removeStudyDeployments method
Remove study deployments with the given studyDeploymentIds.
This also removes all data related to the study deployments managed by
ParticipationService.
Returns the IDs of study deployments which were removed. IDs for which no study deployment exists are ignored.
Implementation
@override
Future<Set<String>> removeStudyDeployments(Set<String> studyDeploymentIds) =>
throw CarpServiceException(
'Removing study deployments is not supported from the client side.',
);