documentById method
Gets a DocumentReference for the specified unique id for study with id studyId.
studyId can be omitted if specified as part of this service's study.
Implementation
DocumentReference documentById(int id, {String? studyId}) =>
DocumentReference._id(this, getStudyId(studyId), id);