CarpServiceTask class abstract

Base class for asynchronous file tasks started by a FileStorageReference.

See FileUploadTask and FileDownloadTask.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
reference ↔ FileStorageReference
The file reference this task works on.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TaskStateType
no setter

Methods

cancel() → void
Cancels this task.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited