DataPointHeader class

The header (meta-data) attached to all DataPoints, like study, user, time span and data format.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false, explicitToJson: true)

Constructors

DataPointHeader({String? studyId, String? userId, DataType? dataFormat, String? deviceRoleName, String? triggerId, DateTime? startTime, DateTime? endTime})
Create a new DataPointHeader.
DataPointHeader.fromJson(Map<String, dynamic> json)
Create a DataPointHeader from a JSON map.
factory

Properties

dataFormat ↔ DataType?
The data format. See DataType and NameSpace.
getter/setter pair
deviceRoleName ↔ String?
The role of the device that collected this data point.
getter/setter pair
endTime ↔ DateTime?
The UTC end timestamp for this data point. If this data point does not cover a period, endTime will be null.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ DateTime?
The UTC start timestamp for this data point.
getter/setter pair
studyId ↔ String?
An ID of this study.
getter/setter pair
triggerId ↔ String?
The id of the trigger in the study deployment that generated this data point.
getter/setter pair
uploadTime ↔ DateTime?
The UTC time stamp of when this data point was uploaded to the server. Set by the server.
getter/setter pair
userId ↔ String?
The ID of the user (if known).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited