DeploymentReference class

Provides a reference to the deployment endpoint in a CARP web service that can handle a specific PrimaryDeviceDeployment.

According to CARP core, the protocol for using the deployment sub-system is:

  • getStatus() - get the study deployment status of this deployment.
  • registerDevice() - register this device - and connected devices - in this deployment
  • get() - get the deployment for this master device
  • deployed() - report the deployment as deployed
  • unRegisterDevice() - unregister this - or other - device if no longer used
Inheritance

Properties

deployment → PrimaryDeviceDeployment?
The deployment for this master device, once fetched from CAWS. Returns null if the deployment is not yet known.
no setter
deviceRoleName String
The role name of the primary device in this deployment.
no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setterinherited
registeredDeviceId String
A unique id for this device as registered at CARP.
no setter
rpcEndpointUri String
The URL for the deployment endpoint.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service CarpBaseService
getter/setter pairinherited
status → StudyDeploymentStatus?
The latest known deployment status for this master device fetched from CAWS. Returns null if status is not yet known.
no setter
studyDeploymentId String
The CARP study deployment ID.
no setter

Methods

deployed() Future<StudyDeploymentStatus>
Mark this deployment as a deployed on the server.
get() Future<SmartphoneDeployment>
Get the deployment for this DeploymentReference for the specified studyDeploymentId.
getStatus() Future<StudyDeploymentStatus>
Refresh the deployment status for this DeploymentReference from CAWS.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDevice([DeviceRegistration? registration]) Future<StudyDeploymentStatus>
Register this device with deviceRoleName with registration for this deployment at the CARP server. If registration is null, a default registration will be created
toString() String
A string representation of this object.
inherited
unRegisterDevice() Future<StudyDeploymentStatus>
Unregister deviceRoleName for this deployment at the CARP server.

Operators

operator ==(Object other) bool
The equality operator.
inherited