FileDownloadTask class

A task supporting asynchronous download of a file.

Inheritance

Properties

file ↔ File
The file on the local device which this task is downloading to. The file has to be created before starting the download.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onComplete → Future<int>
Returns the HTTP status code when completed
no setter
reference ↔ FileStorageReference
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TaskStateType
no setterinherited

Methods

cancel() → void
Cancel the download task
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited