FileStorageReference class

Provide a file endpoint reference to a CARP web service. Used to:

  • upload a local File to the CARP server
  • download a CARP file to a local File
  • get a CarpFileResponse file object from the CARP sever
  • get all file object as a list of CarpFileResponses from the CARP sever
  • delete a file at CARP
Inheritance

Properties

fileEndpointUri → String
The URL for the file end point for this FileStorageReference.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
no setterinherited
id ↔ int
The CARP server-side ID of this file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ CarpBaseService
getter/setter pairinherited
studyId → String
The id of the study for this document.
no setter

Methods

delete() → Future<void>
Deletes the file at this FileStorageReference.
download(File file) → FileDownloadTask
Asynchronously downloads the object at this FileStorageReference to a specified local file.
get() → Future<CarpFileResponse>
Get the file object at the server for this FileStorageReference.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(File file, [Map<String, String>? metadata]) → FileUploadTask
Asynchronously uploads a file to the currently specified FileStorageReference, with optional metadata.

Operators

operator ==(Object other) → bool
The equality operator.
inherited