FileUploadTask class

A task supporting asynchronous upload of a file.

Inheritance

Properties

file ↔ File
The file to upload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>
Metadata for the file.
getter/setter pair
name → String
The file name
no setter
onComplete → Future<CarpFileResponse>
no setter
reference ↔ FileStorageReference
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TaskStateType
no setterinherited

Methods

cancel() → void
Cancel the upload task
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited