HTTPStatus class

An HTTP status code and its reason phrase, as held by a CarpServiceRequestException.

See https://en.wikipedia.org/wiki/List_of_HTTP_status_codes

Constructors

HTTPStatus(int httpResponseCode)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpReasonPhrase → String
The reason phrase for httpResponseCode, or "Unknown Status Code" if it is not in httpStatusPhrases.
no setter
httpResponseCode → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

httpStatusPhrases → const Map<int, String>
Reason phrases for the most common HTTP status codes.