CarpInternalServerException class
A CarpServiceRequestException for HTTP 500 Internal Server Error.
- Inheritance
-
- Object
- CarpServiceException
- CarpServiceRequestException
- CarpInternalServerException
Constructors
- CarpInternalServerException(String message, {String? exception, String? path})
Properties
- exception ↔ String?
-
The Java exception from CARP Core.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpStatus ↔ HTTPStatus
-
The HTTP status from CAWS associated with this exception.
getter/setter pairinherited
- message → String
-
finalinherited
- path ↔ String?
-
The URL path that caused the exception.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited