DataPointReference class
A reference to the legacy data point endpoint of one study deployment in CAWS.
Obtained from the deprecated CarpService.dataPointReference. New code uploads data with CarpDataStreamService instead.
Can be used to:
- Inheritance
-
- Object
- CarpReference
- DataPointReference
Properties
- dataEndpointUri → String
-
The URL of the data point endpoint for this DataPointReference.
no setter
-
fileCachePath
→ Future<
String> -
The local folder where batch writes files before upload.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
The authenticated HTTP headers of service.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service ↔ CarpBaseService
-
The service this reference sends its requests through.
getter/setter pairinherited
- studyDeploymentId → String
-
The study deployment id of this data point reference.
no setter
Methods
-
batch(
List< DataPoint> batch) → Future<void> - Batch uploads a list of DataPoints.
-
count(
[String query = '']) → Future< int> -
The number of data points matching the
queryfor this deployment. -
delete(
int id) → Future< void> -
Deletes a data point with the given
id. -
get(
int id) → Future< DataPoint> -
Gets a DataPoint based on its
idfrom CAWS. -
getAll(
) → Future< List< DataPoint> > - Gets all DataPoints for this study deployment.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
DataPoint data) → Future< int> -
Uploads
data. -
query(
String query) → Future< List< DataPoint> > - Queries for DataPoints in CAWS using REST SQL (RSQL).
-
toString(
) → String -
A string representation of this object.
inherited
-
upload(
File file) → Future< void> -
Batch uploads the
filecontaining a list of DataPoints to CAWS.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited