delete method
Delete a data point with the given id.
Returns on success. Throws a CarpServiceException if data point is not found or otherwise unsuccessful.
Implementation
Future<void> delete(int id) async {
final url = "$dataEndpointUri/$id";
await service
._delete(url)
.then(
(response) =>
// we don't need the response for anything, but check for errors
service._handleResponse(response),
);
}